aboutsummaryrefslogtreecommitdiff
path: root/gdb/serial.c
diff options
context:
space:
mode:
authorDavid Taylor <taylor@redhat.com>1998-12-31 21:58:30 +0000
committerDavid Taylor <taylor@redhat.com>1998-12-31 21:58:30 +0000
commit65b07ddca8832033e0e102c3a2a0d9f9f5922a9d (patch)
tree7fc8cee254f271f4cc57e64bcb23576fa121e706 /gdb/serial.c
parentc450a7fe3f5214f42118a04639074d0e3883582c (diff)
downloadfsf-binutils-gdb-65b07ddca8832033e0e102c3a2a0d9f9f5922a9d.zip
fsf-binutils-gdb-65b07ddca8832033e0e102c3a2a0d9f9f5922a9d.tar.gz
fsf-binutils-gdb-65b07ddca8832033e0e102c3a2a0d9f9f5922a9d.tar.bz2
all remaining *.c *.h files from hp merge.
Diffstat (limited to 'gdb/serial.c')
-rw-r--r--gdb/serial.c17
1 files changed, 9 insertions, 8 deletions
diff --git a/gdb/serial.c b/gdb/serial.c
index 89a116e..07638ed 100644
--- a/gdb/serial.c
+++ b/gdb/serial.c
@@ -39,10 +39,10 @@ static serial_t scb_base;
suitable for playback by gdbserver. */
static char *serial_logfile = NULL;
-static FILE *serial_logfp = NULL;
+static GDB_FILE *serial_logfp = NULL;
static struct serial_ops *serial_interface_lookup PARAMS ((char *));
-static void serial_logchar PARAMS ((int chtype, int ch, int timeout));
+static void serial_logchar PARAMS ((int, int, int));
static char logbase_hex[] = "hex";
static char logbase_octal[] = "octal";
static char logbase_ascii[] = "ascii";
@@ -59,15 +59,15 @@ static int serial_current_type = 0;
#define SERIAL_BREAK 1235
static void
-serial_logchar (chtype, ch, timeout)
- int chtype;
+serial_logchar (ch_type, ch, timeout)
+ int ch_type;
int ch;
int timeout;
{
- if (chtype != serial_current_type)
+ if (ch_type != serial_current_type)
{
- fprintf_unfiltered (serial_logfp, "\n%c ", chtype);
- serial_current_type = chtype;
+ fprintf_unfiltered (serial_logfp, "\n%c ", ch_type);
+ serial_current_type = ch_type;
}
if (serial_logbase != logbase_ascii)
@@ -308,7 +308,8 @@ serial_close (scb, really_close)
fputs_unfiltered ("\nEnd of log\n", serial_logfp);
serial_current_type = 0;
- fclose (serial_logfp); /* XXX - What if serial_logfp == stdout or stderr? */
+ /* XXX - What if serial_logfp == gdb_stdout or gdb_stderr? */
+ gdb_fclose (serial_logfp);
serial_logfp = NULL;
}